==> gmaps-0.8.3.tar.gz: package/webpack.config.js <==
var version = require('./package.json').version;

// Custom webpack loaders are generally the same for all webpack bundles, hence
// stored in a separate local variable.
var rules = [
    { test: /\.css$/, loader: 'style-loader!css-loader' },
    { test: /\.less$/, loader: 'style-loader!css-loader!less-loader' },
    { test: /\.js$/, loader: 'babel-loader', query: {presets: ['es2015', 'stage-0']}, exclude: /node_modules/ },
    { test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=application/octet-stream' },
    { test: /\.svg(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=image/svg+xml' },
    { test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=application/font-woff' },
    { test: /\.woff(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=application/font-woff' },
    { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, loader: 'file-loader' },
];

var mode = 'production';


module.exports = [
    {
        // Notebook extension
        //
        // This bundle only contains the part of the JavaScript that is run on
        // load of the notebook. This section generally only performs
        // some configuration for requirejs, and provides the legacy
        // "load_ipython_extension" function which is required for any notebook
        // extension.
        entry: './src/extension.js',
        output: {
            filename: 'extension.js',
            path: __dirname + '/../gmaps/static',
            libraryTarget: 'amd'
        },
        mode: mode
    },
    {
        // Lab plugin
        // This bundle only contains the normalized labplugin.js.
        entry: './src/labplugin.js',
        output: {
            filename: 'labplugin.js',
            path: __dirname + '/jupyterlab-dist',
            libraryTarget: 'amd'
        },
        module: {
            rules: rules
        },
        externals: ['@jupyter-widgets/base', '../dist/index'],
        mode: mode
    },
    {
        // Bundle for the notebook containing the custom widget views and models
        //
        // This bundle contains the implementation for the custom widget views and
        // custom widget.
        // It must be an amd module
        entry: './src/index.js',
        output: {
            filename: 'index.js',
            path: __dirname + '/../gmaps/static',
            libraryTarget: 'amd'
        },
        devtool: 'source-map',
        module: {
            rules: rules
        },
        externals: ['@jupyter-widgets/base', '@jupyter-widgets/controls'],
        mode: mode
    },
    {
        // Embeddable jupyter-gmaps bundle
        //
        // This bundle is generally almost identical to the notebook bundle
        // containing the custom widget views and models.
        //
        // The only difference is in the configuration of the webpack public path
        // for the static assets.
        //
        // It will be automatically distributed by unpkg to work with the static
        // widget embedder.
        //
        // The target bundle is always `dist/index.js`, which is the path required
        // by the custom widget embedder.
        entry: './src/embed.js',
        output: {
            filename: 'index.js',
            path: __dirname + '/dist/',
            libraryTarget: 'amd',
            publicPath: 'https://unpkg.com/jupyter-gmaps@' + version + '/dist/'
        },
        devtool: 'source-map',
        module: {
            rules: rules
        },
        externals: ['@jupyter-widgets/base', '@jupyter-widgets/controls'],
        mode: mode
    }
];

==> gmaps-0.9.0.tar.gz: package/webpack.config.js <==
var version = require('./package.json').version;

// Custom webpack loaders are generally the same for all webpack bundles, hence
// stored in a separate local variable.
var rules = [
    { test: /\.css$/, loader: 'style-loader!css-loader' },
    { test: /\.less$/, loader: 'style-loader!css-loader!less-loader' },
    { test: /\.js$/, loader: 'babel-loader', exclude: /node_modules/ },
    { test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=application/octet-stream' },
    { test: /\.svg(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=image/svg+xml' },
    { test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=application/font-woff' },
    { test: /\.woff(\?v=\d+\.\d+\.\d+)?$/, loader: 'url-loader?limit=10000&mimetype=application/font-woff' },
    { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, loader: 'file-loader' },
];

var mode = 'production';


module.exports = [
    {
        // Notebook extension
        //
        // This bundle only contains the part of the JavaScript that is run on
        // load of the notebook. This section generally only performs
        // some configuration for requirejs, and provides the legacy
        // "load_ipython_extension" function which is required for any notebook
        // extension.
        entry: './src/extension.js',
        output: {
            filename: 'extension.js',
            path: __dirname + '/../gmaps/static',
            libraryTarget: 'amd'
        },
        mode: mode
    },
    {
        // Lab plugin
        // This bundle only contains the normalized labplugin.js.
        entry: './src/labplugin.js',
        output: {
            filename: 'labplugin.js',
            path: __dirname + '/jupyterlab-dist',
            libraryTarget: 'amd'
        },
        module: {
            rules: rules
        },
        externals: ['@jupyter-widgets/base', '../dist/index'],
        mode: mode
    },
    {
        // Bundle for the notebook containing the custom widget views and models
        //
        // This bundle contains the implementation for the custom widget views and
        // custom widget.
        // It must be an amd module
        entry: './src/index.js',
        output: {
            filename: 'index.js',
            path: __dirname + '/../gmaps/static',
            libraryTarget: 'amd'
        },
        devtool: 'source-map',
        module: {
            rules: rules
        },
        externals: ['@jupyter-widgets/base', '@jupyter-widgets/controls'],
        mode: mode
    },
    {
        // Embeddable jupyter-gmaps bundle
        //
        // This bundle is generally almost identical to the notebook bundle
        // containing the custom widget views and models.
        //
        // The only difference is in the configuration of the webpack public path
        // for the static assets.
        //
        // It will be automatically distributed by unpkg to work with the static
        // widget embedder.
        //
        // The target bundle is always `dist/index.js`, which is the path required
        // by the custom widget embedder.
        entry: './src/embed.js',
        output: {
            filename: 'index.js',
            path: __dirname + '/dist/',
            libraryTarget: 'amd',
            publicPath: 'https://unpkg.com/jupyter-gmaps@' + version + '/dist/'
        },
        devtool: 'source-map',
        module: {
            rules: rules
        },
        externals: ['@jupyter-widgets/base', '@jupyter-widgets/controls'],
        mode: mode
    }
];
